s6: the s6-fdholder-setdumpc program
Keywords: s6 s6-fdholder fd-holding fd-holder fd dump storage unix socket activation

s6
Software
skarnet.org

# The `s6-fdholder-setdumpc` program

`s6-fdholder-setdumpc` talks to a fd-holding daemon on its open descriptors 6 and 7, and transmits it a set of file descriptors together with a list of identifiers and expiration dates found in its environment.

## Interface

         s6-fdholder-setdumpc [ -t timeout ]

- s6-fdholder-setdumpc expects to talk to a listening s6-fdholderd program on its descriptors 6 and 7.
- It attempts to pass a complete state - i.e. a set of file descriptors with identifiers and expiration dates - to s6-fdholderd.
- It then exits 0, or 1 if the server returned an error.

## Options

- `-t timeout` : if the operation cannot be processed in timeout milliseconds, then fail with an error message. Communications with the server should be near-instant, so this option is only here to protect users against programming errors.

## Notes

- The error messages for the s6-fdholder suite are explained here.
- The format of the environment variables where s6-fdholder-setdumpc gets its information from is the same as the one set by s6-fdholder-getdumpc.
- Getting the whole state of a s6-fdholderd daemon requires specific privileges. Make sure you properly configure the s6-fdholderd access rights so your client can perform that operation.